@@ -6,6 +6,8 @@
 #'
 #' @param seminr_model A \code{seminr_model} containing the estimated seminr model.
 #'
+#' @return A SEMinR model object which has been adjusted according to PLSc.
+#'
 #' @usage
 #' PLSc(seminr_model)
 #'
@@ -104,12 +106,10 @@ PLSc <- function(seminr_model) {
 
 # Function to implement PLSc as per Dijkstra, T. K., & Henseler, J. (2015). Consistent Partial Least Squares Path Modeling, 39(X).
 model_consistent <- function(seminr_model) {
-  # if(!is.null(seminr_model$mobi_xm) && ("C" %in% seminr_model$mmMatrix[,"type"])) {
-  #   cat("Models with interactions cannot be estimated as PLS consistent and therefore no adjustment for PLS consistent has been made\n")
-  # }
   if(!is.null(seminr_model$interactions) && ("C" %in% seminr_model$mmMatrix[, "type"])) {
-    cat("Models with interactions can be estimated as PLS consistent, but are subject to some bias as per Becker et al. (2018)
-        'Estimating Moderating Effects in PLS-SEM and PLSc-SEM: Interaction Term Generation*Data Treatment'\n")
+    message(
+      "Models with interactions can be estimated as PLS consistent, but are subject to some bias as per Becker et al. (2018)\n",
+      "'Estimating Moderating Effects in PLS-SEM and PLSc-SEM: Interaction Term Generation*Data Treatment'")
     seminr_model <- PLSc(seminr_model)
   }
   if(is.null(seminr_model$interactions) && ("C" %in% seminr_model$mmMatrix[, "type"])) {
